/********************************************************************
 * Job Ticket API (JTAPI) fsgjt_contact_info.h
 *  
 * Copyright (c) 2004 High North Inc.
 * Copyright (c) 2004 International Business Machines Corp.
 * Copyright (c) 2004 Seiko-Epson, Inc.
 * Copyright (c) 2004 Till Kamppeter.  
 * Copyright (c) 2004 Free Standards Group.                   
 *                                                                    
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS 
 * COMMON PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR 
 * DISTRIBUTION OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE 
 * OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * fsgjt_cpl.lic and applies to the contents of this file. 
 *******************************************************************/

#ifndef FSGJT_CONTACT_INFO_H
#define FSGJT_CONTACT_INFO_H

#include <fsgjt.h>
#include <fsgjt_enums.h>

/* Defined constant to uniquely identify this type of JTAPI object */
#define FSGJT_CONTACT_INFO_OBJECT  "JCON"

/************************************************************
 * ContactInfo attributes
 ***********************************************************/
/* Single value where type is fsgjt_text_t (Text) */
#define FSGJT_CONTACT_INFO_ADDRESS           "contact-info-address"

/* Single value where type is fsgjt_text_t (Text) */
#define FSGJT_CONTACT_INFO_COMPANY           "contact-info-company"

/* Multiple values where type is fsgjt_uri_t (URI) */
#define FSGJT_CONTACT_INFO_CONTACT_URI \
  "contact-info-contact-uri"

/* Single value where type is fsgjt_text_t (Text) */
#define FSGJT_CONTACT_INFO_DETAILS           "contact-info-details"

/* Single value where type is fsgjt_text_t (Text) */
#define FSGJT_CONTACT_INFO_NAME              "contact-info-name"

/* Multiple values where type is fsgjt_contact_info_role_t */
/* (ContactInfoRoleEnum) */
#define FSGJT_CONTACT_INFO_ROLES             "contact-info-roles"

/************************************************************
 * fsgjtNewContactInfo - Creates a ContactInfo object having
 * the provided name.
 *
 * param (output) fsgjt_object_t* contactInfo - Pointer to
 *      the new ContactInfo object to create
 * param (input) fsgjt_text_t name - Name of person to
 *      contact or NULL if ContactInfo name not specified
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtNewContactInfo(
               fsgjt_object_t* contactInfo,
               fsgjt_text_t name);

#endif /* FSGJT_CONTACT_INFO_H */
