/********************************************************************
 * Job Ticket API (JTAPI) fsgjt_force_page.h
 *  
 * Copyright (c) 2004 High North Inc.
 * Copyright (c) 2004 International Business Machines Corp.
 * Copyright (c) 2004 Seiko-Epson, Inc.
 * Copyright (c) 2004 Till Kamppeter.  
 * Copyright (c) 2004 Free Standards Group.                   
 *                                                                    
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS 
 * COMMON PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR 
 * DISTRIBUTION OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE 
 * OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * fsgjt_cpl.lic and applies to the contents of this file. 
 *******************************************************************/

#ifndef FSGJT_FORCE_PAGE_H
#define FSGJT_FORCE_PAGE_H

#include <fsgjt.h>
#include <fsgjt_enums.h>

/* Defined constant to uniquely identify this type of JTAPI object */
#define FSGJT_FORCE_PAGE_OBJECT    "JFOR"

/************************************************************
 * ForcePage attributes
 ***********************************************************/
/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_FORCE_PAGE_CELL_POSITION_X \
  "force-page-cell-position-x"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_FORCE_PAGE_CELL_POSITION_Y \
  "force-page-cell-position-y"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_FORCE_PAGE_PAGE                "force-page-page"

/* Single value where type is fsgjt_sheet_side_t (SheetSideEnum) */
#define FSGJT_FORCE_PAGE_SHEET_SIDE          "force-page-sheet-side"

/************************************************************
 * fsgjtNewForcePage - Creates a ForcePage object having the
 * provided page and sheet side.
 *
 * param (output) fsgjt_object_t* forcePage - Pointer to the
 *      new ForcePage object to create
 * param (input) fsgjt_int32_t page - Page number where the
 *      force page is to occur
 * param (input) fsgjt_sheet_side_t sheetSide - Sheet side to
 *      force at the provided page number
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtNewForcePage(
               fsgjt_object_t* forcePage,
               fsgjt_int32_t page,
               fsgjt_sheet_side_t sheetSide);

#endif /* FSGJT_FORCE_PAGE_H */
