/********************************************************************
 * Job Ticket API (JTAPI) fsgjt_job.h
 *  
 * Copyright (c) 2004 High North Inc.
 * Copyright (c) 2004 International Business Machines Corp.
 * Copyright (c) 2004 Seiko-Epson, Inc.
 * Copyright (c) 2004 Till Kamppeter.  
 * Copyright (c) 2004 Free Standards Group.                   
 *                                                                    
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS 
 * COMMON PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR 
 * DISTRIBUTION OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE 
 * OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * fsgjt_cpl.lic and applies to the contents of this file. 
 *******************************************************************/

#ifndef FSGJT_JOB_H
#define FSGJT_JOB_H

#include <fsgjt.h>

/* Defined constant to uniquely identify this type of JTAPI object */
#define FSGJT_JOB_OBJECT           "JJOB"

/************************************************************
 * Job attributes
 ***********************************************************/
/* Single value where type is fsgjt_text_t (Text) */
#define FSGJT_JOB_BILLING_CODE               "job-billing-code"

/* Single value where type is fsgjt_object_t (Binding) */
#define FSGJT_JOB_BINDING                    "job-binding"

/* Single value where type is fsgjt_text_t (Text) */
#define FSGJT_JOB_CLIENT_ID                  "job-client-id"

/* Single value where type is fsgjt_collate_t (CollateEnum) */
#define FSGJT_JOB_COLLATE                    "job-collate"

/* Single value where type is fsgjt_text_t (Text) */
#define FSGJT_JOB_COMMENT                    "job-comment"

/* Single value where type is fsgjt_compression_t (CompressionEnum) */
#define FSGJT_JOB_COMPRESSION                "job-compression"

/* Multiple values where type is fsgjt_object_t (ContactInfo) */
#define FSGJT_JOB_CONTACT_INFO               "job-contact-info"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_COPIES                     "job-copies"

/* Single value where type is fsgjt_text_t (Text) */
#define FSGJT_JOB_CREATE_USER_NAME           "job-create-user-name"

/* Multiple values where type is fsgjt_object_t (Destination) */
#define FSGJT_JOB_DESTINATIONS               "job-destinations"

/* Single value where type is fsgjt_mime_type_t (MimeType) */
#define FSGJT_JOB_DOCUMENT_FORMAT            "job-document-format"

/* Single value where type is fsgjt_natural_language_t */
/* (NaturalLanguage) */
#define FSGJT_JOB_DOCUMENT_NATURAL_LANGUAGE \
  "job-document-natural-language"

/* Multiple values where type is fsgjt_object_t (Document) */
#define FSGJT_JOB_DOCUMENTS                  "job-documents"

/* Single value where type is fsgjt_feed_orientation_t */
/* (FeedOrientationEnum) */
#define FSGJT_JOB_FEED_ORIENTATION           "job-feed-orientation"

/* Single value where type is fsgjt_fit_policy_t (FitPolicyEnum) */
#define FSGJT_JOB_FIT_POLICY                 "job-fit-policy"

/* Single value where type is fsgjt_object_t (Folding) */
#define FSGJT_JOB_FOLDING                    "job-folding"

/* Multiple values where type is fsgjt_object_t (ForcePage) */
#define FSGJT_JOB_FORCE_PAGES                "job-force-pages"

/* Single value where type is fsgjt_hold_t (HoldEnum) */
#define FSGJT_JOB_HOLD                       "job-hold"

/* Multiple values where type is fsgjt_object_t (HoleMaking) */
#define FSGJT_JOB_HOLE_MAKING                "job-hole-making"

/* Single value where type is fsgjt_image_alignment_x_t */
/* (ImageAlignmentXEnum) */
#define FSGJT_JOB_IMAGE_ALIGNMENT_X          "job-image-alignment-x"

/* Single value where type is fsgjt_image_alignment_y_t */
/* (ImageAlignmentYEnum) */
#define FSGJT_JOB_IMAGE_ALIGNMENT_Y          "job-image-alignment-y"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_IMAGE_SHIFT_BACK_X         "job-image-shift-back-x"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_IMAGE_SHIFT_BACK_Y         "job-image-shift-back-y"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_IMAGE_SHIFT_FRONT_X        "job-image-shift-front-x"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_IMAGE_SHIFT_FRONT_Y        "job-image-shift-front-y"

/* Multiple values where type is fsgjt_object_t (PageRange) */
#define FSGJT_JOB_INCLUDE_PAGES              "job-include-pages"

/* Multiple values where type is fsgjt_object_t (InsertSheet) */
#define FSGJT_JOB_INSERT_SHEETS              "job-insert-sheets"

/* Single value where type is fsgjt_jog_offset_t (JogOffsetEnum) */
#define FSGJT_JOB_JOG_OFFSET                 "job-jog-offset"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_MARGIN_BOTTOM              "job-margin-bottom"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_MARGIN_LEFT                "job-margin-left"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_MARGIN_RIGHT               "job-margin-right"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_MARGIN_TOP                 "job-margin-top"

/* Single value where type is fsgjt_object_t (Media) */
#define FSGJT_JOB_MEDIA                      "job-media"

/* Single value where type is fsgjt_text_t (Text) */
#define FSGJT_JOB_MESSAGE_TO_OPERATOR        "job-message-to-operator"

/* Single value where type is fsgjt_text_t (Text) */
#define FSGJT_JOB_NAME                       "job-name"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_NUMBER_UP_X                "job-number-up-x"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_NUMBER_UP_Y                "job-number-up-y"

/* Single value where type is fsgjt_output_bin_name_t */
/* (OutputBinNameEnum) */
#define FSGJT_JOB_OUTPUT_BIN_NAME            "job-output-bin-name"

/* Multiple values where type is fsgjt_object_t (PageRange) */
#define FSGJT_JOB_OUTPUT_PAGES               "job-output-pages"

/* Single value where type is fsgjt_page_delivery_t */
/* (PageDeliveryEnum) */
#define FSGJT_JOB_PAGE_DELIVERY              "job-page-delivery"

/* Single value where type is fsgjt_presentation_direction_t */
/* (PresentationDirectionEnum) */
#define FSGJT_JOB_PRESENTATION_DIRECTION \
  "job-presentation-direction"

/* Single value where type is fsgjt_print_quality_t */
/* (PrintQualityEnum) */
#define FSGJT_JOB_PRINT_QUALITY              "job-print-quality"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_PRIORITY                   "job-priority"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_RESOLUTION_X               "job-resolution-x"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_RESOLUTION_Y               "job-resolution-y"

/* Single value where type is fsgjt_rotation_t (RotationEnum) */
#define FSGJT_JOB_ROTATION                   "job-rotation"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_SCALING_FACTOR_X           "job-scaling-factor-x"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_JOB_SCALING_FACTOR_Y           "job-scaling-factor-y"

/* Multiple values where type is fsgjt_object_t (SeparatorSheet) */
#define FSGJT_JOB_SEPARATOR_SHEETS           "job-separator-sheets"

/* Single value where type is fsgjt_sides_t (SidesEnum) */
#define FSGJT_JOB_SIDES                      "job-sides"

/* Single value where type is fsgjt_object_t (Stitching) */
#define FSGJT_JOB_STITCHING                  "job-stitching"

/* Multiple values where type is fsgjt_object_t (Subscription) */
#define FSGJT_JOB_SUBSCRIPTIONS              "job-subscriptions"

/************************************************************
 * fsgjtNewJob - Creates a Job without providing a Document.
 *
 * param (output) fsgjt_object_t* job - Pointer to Job object
 *      to be created
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtNewJob(
               fsgjt_object_t* job);

/************************************************************
 * fsgjtNewJobFromDocument - Creates a Job containing the 
 * provided Document.
 *
 * param (output) fsgjt_object_t* job - Pointer to Job object
 *      to be created
 * param (input) fsgjt_object_t document - Document to be 
 *      contained in this job
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtNewJobFromDocument(
               fsgjt_object_t* job, 
               fsgjt_object_t document);       

#endif /* FSGJT_JOB_H */
